Preprocessing
-------------

The preprocessing module is used to extract features from raw data after reading. The module is split
according to different types of data, such as survey data, sport tracker data or communication data.

Below we have guides for different type of data.

.. toctree::
   :maxdepth: 1
   :caption: Preprocessing data types

   location
   application
   audio
   battery
   communication
   screen
   survey
   tracker
